@@ -1,7 +1,7 @@
-export CONDA_EXE='D:\bld\conda_1574961913256\_h_env\Scripts\conda.exe'
+export CONDA_EXE='D:\bld\conda_1576178757525\_h_env\Scripts\conda.exe'
 export _CE_M=''
 export _CE_CONDA=''
-export CONDA_PYTHON_EXE='D:\bld\conda_1574961913256\_h_env\python.exe'
+export CONDA_PYTHON_EXE='D:\bld\conda_1576178757525\_h_env\python.exe'
 
 # Copyright (C) 2012 Anaconda, Inc
 # SPDX-License-Identifier: BSD-3-Clause
@@ -50,20 +50,24 @@ __conda_activate() {
     \local cmd="$1"
     shift
     \local ask_conda
-    OLDPATH="${PATH}"
+    CONDA_INTERNAL_OLDPATH="${PATH}"
     __add_sys_prefix_to_path
-    ask_conda="$(PS1="$PS1" "$CONDA_EXE" $_CE_M $_CE_CONDA shell.posix "$cmd" "$@")" || \return $?
-    PATH="${OLDPATH}"
+    ask_conda="$(PS1="$PS1" "$CONDA_EXE" $_CE_M $_CE_CONDA shell.posix "$cmd" "$@")" || $?
+    rc=$?
+    PATH="${CONDA_INTERNAL_OLDPATH}"
     \eval "$ask_conda"
+    if [[ $rc != 0 ]]; then
+        \export PATH
+    fi
     __conda_hashr
 }
 
 __conda_reactivate() {
     \local ask_conda
-    OLDPATH="${PATH}"
+    CONDA_INTERNAL_OLDPATH="${PATH}"
     __add_sys_prefix_to_path
     ask_conda="$(PS1="$PS1" "$CONDA_EXE" $_CE_M $_CE_CONDA shell.posix reactivate)" || \return $?
-    PATH="${OLDPATH}"
+    PATH="${CONDA_INTERNAL_OLDPATH}"
     \eval "$ask_conda"
     __conda_hashr
 }
@@ -79,11 +83,11 @@ conda() {
                 __conda_activate "$cmd" "$@"
                 ;;
             install|update|upgrade|remove|uninstall)
-                OLDPATH="${PATH}"
+                CONDA_INTERNAL_OLDPATH="${PATH}"
                 __add_sys_prefix_to_path
                 "$CONDA_EXE" $_CE_M $_CE_CONDA "$cmd" "$@"
                 \local t1=$?
-                PATH="${OLDPATH}"
+                PATH="${CONDA_INTERNAL_OLDPATH}"
                 if [ $t1 = 0 ]; then
                     __conda_reactivate
                 else
@@ -91,11 +95,11 @@ conda() {
                 fi
                 ;;
             *)
-                OLDPATH="${PATH}"
+                CONDA_INTERNAL_OLDPATH="${PATH}"
                 __add_sys_prefix_to_path
                 "$CONDA_EXE" $_CE_M $_CE_CONDA "$cmd" "$@"
                 \local t1=$?
-                PATH="${OLDPATH}"
+                PATH="${CONDA_INTERNAL_OLDPATH}"
                 return $t1
                 ;;
         esac
@@ -120,4 +124,3 @@ if [ -z "${CONDA_SHLVL+x}" ]; then
         PS1=
     fi
 fi
-
