@@ -228,6 +228,10 @@ class SatSolverChoice(Enum):
 PACKAGE_CACHE_MAGIC_FILE = 'urls.txt'
 PREFIX_MAGIC_FILE = join('conda-meta', 'history')
 
+PREFIX_STATE_FILE = join('conda-meta', 'state')
+PACKAGE_ENV_VARS_DIR = join('etc', 'conda', 'env_vars.d')
+CONDA_ENV_VARS_UNSET_VAR = "***unset***"
+
 
 # TODO: should be frozendict(), but I don't want to import frozendict from auxlib here.
 NAMESPACES_MAP = {  # base package name, namespace
