@@ -228,11 +228,6 @@ def configure_parser_clean(sub_parsers):
         action="store_true",
         help="Remove index cache.",
     )
-    removal_target_options.add_argument(
-        "-l", "--lock",
-        action="store_true",
-        help="Remove all conda lock files.",
-    )
     removal_target_options.add_argument(
         '-p', '--packages',
         action='store_true',
@@ -518,7 +513,7 @@ def configure_parser_config(sub_parsers):
 
 def configure_parser_create(sub_parsers):
     help = "Create a new conda environment from a list of specified packages. "
-    descr = (help + "To use the created environment, use 'source activate "
+    descr = (help + "To use the created environment, use 'conda activate "
              "envname' look in that directory first.  This command requires either "
              "the -n NAME or -p PREFIX option.")
 
